UmInitDouYin class

初始抖音 @AppKey 钉钉应用 AppKey

Implemented types

Constructors

UmInitDouYin({required String appKey, required String appSecret})

Properties

appKey String
final
appSecret String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited